iodebug

package
v1.13.13 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 23, 2026 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AddBytesRead

func AddBytesRead(n int64)

func AddBytesWritten

func AddBytesWritten(n int64)

func FlushProcessCounters

func FlushProcessCounters(command string, subcommand string) error

func IncBlockDecode added in v1.8.0

func IncBlockDecode()

func IncContainerAppend

func IncContainerAppend()

func IncContainerClose

func IncContainerClose()

func IncContainerOpen

func IncContainerOpen()

func IncFsync

func IncFsync()

func IncSnapshotMetadataWrite

func IncSnapshotMetadataWrite()

func StartOperation

func StartOperation()

StartOperation resets in-process metrics so captured counters are scoped to one command execution rather than cumulative process lifetime totals.

Types

type Counters

type Counters struct {
	ContainerAppendCount   int64 `json:"container_append_count"`
	FsyncCount             int64 `json:"fsync_count"`
	ContainerOpenCount     int64 `json:"container_open_count"`
	ContainerCloseCount    int64 `json:"container_close_count"`
	BytesWritten           int64 `json:"bytes_written"`
	BytesRead              int64 `json:"bytes_read"`
	SnapshotMetadataWrites int64 `json:"snapshot_metadata_write_count"`
	BlockDecodeCount       int64 `json:"block_decode_count"`
}

func Snapshot

func Snapshot() Counters

Jump to