Documentation
¶
Index ¶
- type Edge
- type EntityType
- type GCRootOptions
- type NodeID
- type Service
- func (s *Service) CurrentLogicalFileRoots(ctx context.Context) ([]NodeID, error)
- func (s *Service) GCRoots(ctx context.Context, opts GCRootOptions) ([]NodeID, error)
- func (s *Service) GetOutgoing(ctx context.Context, n NodeID) ([]NodeID, error)
- func (s *Service) GetReachableChunks(ctx context.Context, snapshotIDs []string) (map[int64]struct{}, error)
- func (s *Service) GetReverseReferences(ctx context.Context, target NodeID) ([]NodeID, error)
- func (s *Service) ReachableChunksFromRoots(ctx context.Context, roots []NodeID) (map[int64]struct{}, error)
- func (s *Service) ReachableChunksFromRootsWithOptions(ctx context.Context, roots []NodeID, opts TraversalOptions) (map[int64]struct{}, error)
- func (s *Service) SnapshotRoots(ctx context.Context, excludeSnapshotIDs []string) ([]NodeID, error)
- func (s *Service) Traverse(ctx context.Context, start []NodeID, visit func(NodeID) error) error
- func (s *Service) TraverseWithOptions(ctx context.Context, start []NodeID, visit func(NodeID) error, ...) error
- type TraceEvent
- type TraceFunc
- type TraversalOptions
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type EntityType ¶
type EntityType string
const ( EntitySnapshot EntityType = "snapshot" EntityLogicalFile EntityType = "logical_file" EntityChunk EntityType = "chunk" EntityContainer EntityType = "container" )
type GCRootOptions ¶
type GCRootOptions struct {
ExcludeSnapshots []string
}
GCRootOptions configures root collection for GC mark traversal.
type Service ¶
type Service struct {
// contains filtered or unexported fields
}
func NewService ¶
func (*Service) CurrentLogicalFileRoots ¶
CurrentLogicalFileRoots returns logical-file roots from the current repository state (physical_file table).
func (*Service) GCRoots ¶
GCRoots returns the full GC root set: current logical files plus snapshot logical files, with optional snapshot exclusions.
func (*Service) GetOutgoing ¶
func (*Service) GetReachableChunks ¶
func (*Service) GetReverseReferences ¶
func (*Service) ReachableChunksFromRoots ¶
func (s *Service) ReachableChunksFromRoots(ctx context.Context, roots []NodeID) (map[int64]struct{}, error)
ReachableChunksFromRoots traverses the graph from arbitrary roots and returns all reachable chunk IDs.
func (*Service) ReachableChunksFromRootsWithOptions ¶
func (*Service) SnapshotRoots ¶
SnapshotRoots returns logical-file roots retained by snapshots, excluding any snapshot IDs explicitly listed in excludeSnapshotIDs.
func (*Service) TraverseWithOptions ¶
type TraceEvent ¶
type TraceFunc ¶
type TraceFunc func(TraceEvent)
type TraversalOptions ¶
type TraversalOptions struct {
Trace TraceFunc
}
Click to show internal directories.
Click to hide internal directories.