Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ContainsNUL ¶
ContainsNUL reports whether the input contains a NUL byte.
func IsWindowsDrivePath ¶
IsWindowsDrivePath reports whether p starts with a Windows drive prefix. Examples: C:\\tmp\\a.txt, D:/tmp/a.txt, E:
func ValidatePathHasNoSymlinkComponents ¶
ValidatePathHasNoSymlinkComponents rejects paths that traverse existing symlink components. Missing suffix components are allowed.
func ValidateSafeFileName ¶
ValidateSafeFileName validates an opaque filename intended to be joined under a trusted directory.
func ValidateStoredRelativePath ¶
ValidateStoredRelativePath validates a stored/snapshot-style relative path.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.